@@ -107,6 +107,7 @@ class EmisGrid(object):
         pn.save(file_, emis_grid=self.emis_grid, tem=self.tem, den=self.den, elem=self.elem,
              spec=self.spec, atomFitsFile=self.atomFitsFile, collFitsFile=self.collFitsFile)
 
+
     def getGrid(self, lev_i=None, lev_j=None, wave= -1, to_eval=None):
         """
         2D array of a line emissivity for the (Te, Ne) values of a regularly spaced grid.
@@ -119,7 +120,7 @@ class EmisGrid(object):
             - to_eval        algebraic expression of the line combination to evaluate
         
         """
-        if wave != -1 :
+        if wave != -1:
             lev_i, lev_j = self.atom.getTransition(wave)
 
         if to_eval is None:
@@ -131,6 +132,7 @@ class EmisGrid(object):
             return self.getGrid(wave=wave)
         return eval(to_eval)
     
+    
     def plotImage(self, to_eval=None, lev_i1=None, lev_j1=None, lev_i2=None, lev_j2=None,
                   wave1= -1, wave2= -1, cblabel='', **kwargs):
         """
@@ -155,9 +157,9 @@ class EmisGrid(object):
         L = lambda lam: self.getGrid(wave=lam)
         I = lambda i, j: self.getGrid(i, j)
         if to_eval is None:
-            if wave1 != -1 :
+            if wave1 != -1:
                 lev_i1, lev_j1 = self.atom.getTransition(wave1)
-            if wave2 != -1 :
+            if wave2 != -1:
                 lev_i2, lev_j2 = self.atom.getTransition(wave2)
             to_eval = 'I(' + str(lev_i1) + ',' + str(lev_j1) + ') / I(' + str(lev_i2) + ',' + str(lev_j2) + ')'
         X = np.log10(self.den2D)
@@ -304,7 +306,7 @@ def getEmisGridDict(elem_list=None, spec_list=None, atom_list=None, restore=True
             n_tem=100, n_den=100, tem_min=5000., tem_max=20000., den_min=10., den_max=1e8, save=True,
             atomDict=None, createPypicsDir=True, computeIfAbsent=True):
     """
-    Return a dictionary of EmisGrid objects refereed by their atom string (e.g. 'O3').
+    Return a dictionary of EmisGrid objects referred to by their atom string (e.g. 'O3').
     
     Usage:
         emisgrids = pn.getEmisGridDict(['C', 'N', 'O'], [2, 3], save=True)
@@ -332,23 +334,11 @@ def getEmisGridDict(elem_list=None, spec_list=None, atom_list=None, restore=True
     """
     if pypic_path is None:
         pypic_path = pn.config.pypic_path
+    else:
+        pn.config.pypic_path = pypic_path
     calling = 'getEmisGridDict'
-    if restore or save:
-        if pypic_path is None:
-            pn.log_.error('Unable to find pypic_path directory', calling=calling)
-            return None
-        if not os.path.isdir(pypic_path):
-            if createPypicsDir:
-                try:
-                    os.makedirs(pypic_path)
-                except:
-                    pn.log_.error('Unable to create {0} directory', calling=calling)
-                    return None
-                pn.log_.message('Creating the {0} directory'.format(pypic_path), calling=calling)
-            else:
-                pn.log_.error('Directory {0} does not exist, you may use the createPypicsDir=True option'.format(pypic_path),
-                              calling=calling)
-                return None
+    if pypic_path is None:
+        return None
     emis_grids = {}
     atoms = []
     if atomDict is not None:
