@@ -1,7 +1,7 @@
 import numpy as np
 import pyneb as pn
 from pyneb.utils.init import ELEM_LIST, SPEC_LIST
-
+from pyneb.utils.misc import parseAtom
 
 class ICF(object):
 
@@ -372,18 +372,16 @@ class ICF(object):
                                       'icf': '(abun["O2"] + abun["O3"]) / abun["O2"]',
                                       'type': 'All',
                                       'comment': 'Based on PNe and HII data with log(O2/O3) > -0.1. It is assumed that O/H = (O+ + O++) / H+'},
-                         'G07_1.d2': {'elem': 'Cl',
+                         'GKA07_1.p269': {'elem': 'Cl',
                                       'atom': 'abun["Cl3"]',
                                       'icf': '(elem_abun["direct_He.23"] / abun["He2"])**2',
                                       'type': 'PNe',
                                       'comment': 'Based on photoionization models'},
-                         'G07_1.P92': {'elem': 'Cl',
+                         'mGKA07-PTPR92_p269': {'elem': 'Cl',
                                       'atom': 'abun["Cl3"]',
                                       'icf': '(elem_abun["PTPR92_21"] / abun["He2"])**2',
                                       'type': 'PNe',
                                       'comment': 'Based on photoionization models'},
-                         
-                         
                          'DIMS14_10': {'elem': 'He',
                                        'atom':'abun["He2"] + abun["He3"]', 
                                        'icf': '1.0',
@@ -521,11 +519,11 @@ class ICF(object):
 # Corrected with PTPR92
 #                             'GRal04': {'ref': 'Garcia-Rojas et al 2004, ApJS, 153, 501',
 #                                      'url': 'http://adsabs.harvard.edu/abs/2004ApJS..153..501G'},
-#                             'G07': {'ref': 'Girard, Koeppen and Acker 2007, A&A, 463, 265',
-#                                      'url': 'http://adsabs.harvard.edu/abs/2007A%26A...463..265G'},
-                              'PTPR92': {'ref': 'Peimbert et al 1992, RMAA, 24, 155',
+                             'GKA07': {'ref': 'Girard, Koeppen and Acker 2007, A&A, 463, 265',
+                                      'url': 'http://adsabs.harvard.edu/abs/2007A%26A...463..265G'},
+                             'PTPR92': {'ref': 'Peimbert, Torres-Peimbert and Ruiz 1992, RMAA, 24, 155',
                                         'url': 'http://adsabs.harvard.edu/abs/1992RMxAA..24..155P'},
-                             'DIMS14': {'ref': 'Delgado-Inglada et al., 2014, MNRAS',
+                             'DIMS14': {'ref': 'Delgado-Inglada, Morisset and Stasinska, 2014, MNRAS',
                                         'url':'http://arxiv.org/abs/1402.4852'}
                              }
 
@@ -700,7 +698,13 @@ class ICF(object):
 
         """        
         paper = label.split('_')[0]
-        return self.all_icf_refs[paper]['ref']
+        if paper[0] == 'm':
+            paper1 = paper.split('-')[0][1:]
+            paper2 = paper.split('-')[1]
+            mixed = self.all_icf_refs[paper1]['ref'] + ' using an abundance based on ' + self.all_icf_refs[paper2]['ref']
+            return mixed
+        else:
+            return self.all_icf_refs[paper]['ref']
    
     
     def getURL(self, label): 
@@ -712,7 +716,13 @@ class ICF(object):
 
         """        
         paper = label.split('_')[0]
-        return self.all_icf_refs[paper]['url']
+        if paper[0] == 'm':
+            paper1 = paper.split('-')[0][1:]
+            paper2 = paper.split('-')[1]
+            mixed = self.all_icf_refs[paper1]['url'] + ' using an abundance based on ' + self.all_icf_refs[paper2]['url']
+            return mixed
+        else:
+            return self.all_icf_refs[paper]['url']
    
     
     def getExpression(self, label): 
@@ -754,7 +764,7 @@ class ICF(object):
         """
         return self.all_icfs[label]['comment']
 
-    def getElemAbundance(self, atom_abun, icf_list=[], absentIon=np.nan):
+    def getElemAbundance(self, atom_abun, icf_list=[], absentIon=np.nan, use_coll=True):
         """
         Compute elemental abundances from ionic abundances. The complete iventory is printed through pn.ICF().printAllICFs().
         See the ICF class for more details.
@@ -763,10 +773,11 @@ class ICF(object):
         Parameters: 
            - atom_abun    a dictionary of ionic abundances
            - icf_list     a list of selected ICFs (default: all)
-    
+           - use_coll     In case both collision lines and recombination lines abundances exists:
+                           if True (default), use collision line ionic abundance, if false use recombination ones  
         Usage:
             atom_abun = {'O2': 0.001, 'O3': 0.002, 'Ne3': 1.2e-5}
-            pn.getElemAbundance(atom_abun)
+            getElemAbundance(atom_abun)
          
         """
         if type(icf_list) == type(''):
@@ -776,15 +787,23 @@ class ICF(object):
         for elem in ELEM_LIST:
             for spec in SPEC_LIST:
                 atom_list.append(elem + str(spec)) 
-        atom_list.append('He2')
-        atom_list.append('He3')
+        atom_list.extend(['He2', 'He3', 'He1r', 'He2r', 'O2r'])
     
         # Initialize the ionic abundances so that the code does not crash when a specific abundance is invoked
         abun = {}
         for atom in atom_list:
             # Set those abundances which are different from 0. These determine which ICFs can be computed        
             if atom in atom_abun:
-                abun[atom] = atom_abun[atom]
+                if atom[-1] == 'r':
+                    elem, spec = parseAtom(atom[:-1])
+                    atomc = elem + str(int(spec)+1)
+                    if (not use_coll) or (atomc not in atom_abun):
+                        abun[atomc] = atom_abun[atom]
+                else:
+                    elem, spec = parseAtom(atom)
+                    atomr = elem + str(int(spec)-1) + 'r'
+                    if use_coll or (atomr not in atom_abun):
+                        abun[atom] = atom_abun[atom]
             else:
                 abun[atom] = absentIon
         self.abun = abun
