@@ -44,13 +44,13 @@ class RedCorr(object):
             RC.getCorr(5007)
         
         Parameters:
-            - E_BV [float] : differential extinction between bands B and V
+            - E_BV [float]: differential extinction between bands B and V
             - R_V = AV/E_BV
-            - law [str] : one of the defined laws (available with RedCorr.getLaws()) 
-            - cHbeta : logarithmic extinction a Hbeta (prevalence on E_BV)
-            - UserFunction X(wave, param): A user-defined function that accept 2 parameters : wavelength(s) in Angstrom 
+            - law [str]: one of the defined laws (available with RedCorr.getLaws()) 
+            - cHbeta: logarithmic extinction a Hbeta (prevalence on E_BV)
+            - UserFunction X(wave, param): A user-defined function that accept 2 parameters: wavelength(s) in Angstrom 
             and an optional parameter and return X(lambda) = A(lambda)/E_BV = R.A(lambda)/AV. 
-            The correction is : 10**(0.4*E_bv*X)
+            The correction is: 10**(0.4*E_bv*X)
             
         """
         
@@ -62,7 +62,7 @@ class RedCorr(object):
         self._laws_dict['B 07'] = self._B07
         self._laws_dict['oD 94'] = self._oD94
         self._laws_dict['S 79 H 83'] = self._SH
-        self._laws_dict['GCC 09'] = self._GCC09
+        #self._laws_dict['GCC 09'] = self._GCC09 
         self._laws_dict['K 76'] = self._K76
         self._laws_dict['Gal SM 79'] = self._Gal_SM79
         self._laws_dict['LMC G 03'] = self._LMC_Gordon03
@@ -503,7 +503,8 @@ class RedCorr(object):
         return np.squeeze(Xx)
     
     
-    def _GCC09(self, wave):
+    # Removed from the code because it is most probably wrong
+    #def _GCC09(self, wave):
         """
         Gordon, Cartledge & Clayton 2009, ApJ, 705, 1320
         http://adsabs.harvard.edu/abs/2009ApJ...705.1320G
@@ -516,6 +517,7 @@ class RedCorr(object):
         Scope:
         UV
            
+        """
         """
         x = 1e4 / np.asarray([wave]) # inv microns
         Xx = np.zeros_like(x)
@@ -547,6 +549,7 @@ class RedCorr(object):
         Xx[tt] = self.R_V * a + b
 
         return np.squeeze(Xx)
+        """
 
     def _K76(self, wave):
         """
