@@ -1,10 +1,16 @@
 import os
 import pyneb as pn
 import numpy as np
-from misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman
+import re
+from misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman, strExtract
 from init import ELEM_LIST, SPEC_LIST
 from physics import _predefinedDataFileDict
 
+def atom2chianti(atom):
+    elem = parseAtom(atom)[0]
+    spec = int(parseAtom(atom)[1])
+    return '{0}_{1}'.format(elem.lower(), spec)
+
 class _ManageAtomicData(object):
     
     def __init__(self):
@@ -17,9 +23,14 @@ class _ManageAtomicData(object):
         self.addDataFilePath('../atomic_data/', inPyNeb=True)
         self.addDataFilePath('./')
         self._RecombData = {}
-        self.plot_path = execution_path('../plot/level_diagrams/')
+        self._initChianti()
 
+    def includeFitsPath(self):
+        self.addDataFilePath('../atomic_data_fits/old_fits/', inPyNeb=True)
 
+    def removeFitsPath(self):
+        self.removeDataFilePath('../atomic_data_fits/old_fits/')
+        
     def getPredefinedDataFileDict(self, data_dict=None):
         """
         Retrieve a predefined dictionary of atomic data (either the default one [data_dict unspecified]
@@ -115,7 +126,11 @@ class _ManageAtomicData(object):
             try:
                 self._DataFilePaths.remove(os.path.abspath(fits_dir))
             except:
-                self.log_.warn('{0} could not be removed from the path list', calling=self.calling)
+                pass
+            try:
+                self._DataFilePaths.remove(execution_path(fits_dir))
+            except:
+                pass
  
                 
     def getAllDataFilePaths(self):
@@ -135,9 +150,20 @@ class _ManageAtomicData(object):
            - data_file    name of the file
 
         """
+        
         for dir in self._DataFilePaths:
             if data_file in os.listdir(dir):
                 return dir
+        strs = data_file.split('_')
+        elem = strs[0].capitalize()
+        spec = roman_to_int(strs[1])
+        atom = elem + str(spec)
+        strs = re.split(r'[_.]+',data_file)
+        data_type = strs[2]
+        if (data_type == 'atom') and (atom2chianti(atom) in self.ChiantiIONS['atom']):
+            return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
+        if (data_type == 'coll') and (atom2chianti(atom) in self.ChiantiIONS['coll']):
+            return('{}/{}/{}'.format(self.Chianti_path, elem.lower(), atom2chianti(atom)))
         return None
  
     
@@ -170,17 +196,35 @@ class _ManageAtomicData(object):
 
         """
         file_list = []
+        if data_type is None:
+            data_types = ['atom', 'coll', 'rec']
+        else:
+            data_types = [data_type]
         if atom is not None:
             elem, spec = parseAtom(atom)
             elem = elem.lower()
             spec = int_to_roman(int(spec)).lower()
             atom_str = '{0}_{1}_'.format(elem, spec)
+            if atom2chianti(atom) in self.ChiantiIONS['atom']:
+                if 'atom' in data_types:
+                    file_list.append('{0}_{1}_atom.chianti'.format(elem, spec))
+            if atom2chianti(atom) in self.ChiantiIONS['coll']:
+                if 'coll' in data_types:
+                    file_list.append('{0}_{1}_coll.chianti'.format(elem, spec))
         else:
             atom_str = '.'
-        if data_type is None:
-            data_types = ['atom', 'coll', 'rec']
-        else:
-            data_types = [data_type]
+            for atom in self.ChiantiIONS['atom']:
+                elem, spec = parseAtom(atom)
+                elem = elem.lower()
+                spec = int_to_roman(int(spec)).lower()
+                if 'atom' in data_types:
+                    file_list.append('{0}_{1}_atom.chianti'.format(elem, spec))
+            for atom in self.ChiantiIONS['coll']:
+                elem, spec = parseAtom(atom)
+                elem = elem.lower()
+                spec = int_to_roman(int(spec)).lower()
+                if 'coll' in data_types:
+                    file_list.append('{0}_{1}_coll.chianti'.format(elem, spec))
         for dir in self._DataFilePaths:
             files = os.listdir(dir)
             for file in files:
@@ -188,6 +232,8 @@ class _ManageAtomicData(object):
                     for dt in data_types:
                         if dt in file:
                             file_list.append(file)
+                            
+        file_list.sort()
         return file_list
     
     
@@ -226,56 +272,6 @@ class _ManageAtomicData(object):
         return [coll_atom_list, rec_atom_list] 
         
     
-    def setDataFile(self, data_file=None, atom=None, data_type=None):
-        """
-        Associate an atomic data file to an atom and a type of data, which is one of 
-            ('atom', 'coll', 'rec').
-
-        Usage:
-            pn.atomicData.setDataFile('cl_iii_atom_M83-KS86.fits')
-            pn.atomicData.setDataFile('TEST.fits', 'O3', 'atom') # but the previous way 
-                to name the files is preferred
-
-        Parameters:
-            - data_file    atomic data file. 
-            - [atom]         selected atom
-            - [data_type]    'atom', 'coll', 'rec'
-            If atom and data_type not set, file format is assumed to be e.g. o_iii_coll_REF.fits
-
-        """          
-        if atom is None:
-            strs = data_file.split('_')
-            elem = strs[0].capitalize()
-            spec = roman_to_int(strs[1])
-            atom = elem + str(spec)
-        else:
-            elem, spec = parseAtom(atom)
-        if data_type is None:
-            strs = data_file.split('_')
-            data_type = strs[2]
-        if data_type not in ('atom', 'coll', 'rec'):
-            self.log_.error('{0} is not a valid type'.format(data_type))
-            return None
-        if elem not in ELEM_LIST:
-            self.log_.error('{0} is not a valid element'.format(elem))
-            return None
-        if atom not in self._DataFileDict:
-            self._DataFileDict[atom] = {}
-        if self.getDirForFile(data_file) is not None:
-            self._DataFileDict[atom][data_type] = data_file
-            # as something changed, predefined is not valid anymore
-            self.predefined = None
-            if data_type == 'rec':
-                if atom in self._RecombData:
-                    del self._RecombData[atom]
-            self.log_.message('Adding {0} {1} data for {2}'.format(data_file, data_type, atom), calling=self.calling)
-        else:
-            self.log_.warn('Unknown file or File path of {0} not included in list. Run addDataFilePath first'.format(data_file),
-                           calling=self.calling)
-        if (atom == 'H1') and ('H1' in pn.atomicData._RecombData):
-            del pn.atomicData._RecombData['H1']
-
-
     def getAllAtoms(self, coll=True, rec=False):
         """
         Return a list of all the atoms (e.g. 'O3') included in the adopted dictionary 
@@ -378,7 +374,57 @@ class _ManageAtomicData(object):
                     if names[2] in ('atom', 'coll', 'rec'):
                         self.setDataFile(atom, names[2], file_)
  
- 
+    def setDataFile(self, data_file=None, atom=None, data_type=None):
+        """
+        Associate an atomic data file to an atom and a type of data, which is one of 
+            ('atom', 'coll', 'rec').
+
+        Usage:
+            pn.atomicData.setDataFile('cl_iii_atom_M83-KS86.fits')
+            pn.atomicData.setDataFile('TEST.fits', 'O3', 'atom') # but the previous way 
+                to name the files is preferred
+            pn.atomicData.setDataFile('o_iii_atom.chianti')
+
+        Parameters:
+            - data_file    atomic data file. 
+            - [atom]         selected atom
+            - [data_type]    'atom', 'coll', 'rec'
+            If atom and data_type not set, file format is assumed to be e.g. o_iii_coll_REF.fits
+
+        """          
+        if atom is None:
+            strs = data_file.split('_')
+            elem = strs[0].capitalize()
+            spec = roman_to_int(strs[1])
+            atom = elem + str(spec)
+        else:
+            elem, spec = parseAtom(atom)
+        if data_type is None:
+            strs = re.split(r'[_.]+',data_file)
+            data_type = strs[2]
+        if data_type not in ('atom', 'coll', 'rec'):
+            self.log_.error('{0} is not a valid type'.format(data_type))
+            return None
+        if elem not in ELEM_LIST:
+            self.log_.error('{0} is not a valid element'.format(elem))
+            return None
+        if atom not in self._DataFileDict:
+            self._DataFileDict[atom] = {}
+        if self.getDirForFile(data_file) is not None:
+            self._DataFileDict[atom][data_type] = data_file
+            # as something changed, predefined is not valid anymore
+            self.predefined = None
+            if data_type == 'rec':
+                if atom in self._RecombData:
+                    del self._RecombData[atom]
+            self.log_.message('Adding {0} {1} data for {2}'.format(data_file, data_type, atom), calling=self.calling)
+        else:
+            self.log_.error('Unknown file {0} or corresponding File path not included in list. Run addDataFilePath first'.format(data_file),
+                           calling=self.calling)
+        if (atom == 'H1') and ('H1' in pn.atomicData._RecombData):
+            del pn.atomicData._RecombData['H1']
+
+
     def printAllSources(self, at_set=None, predef=None):
         """
         Print bibliographic sources for atomic data of a set of atoms.
@@ -408,12 +454,35 @@ class _ManageAtomicData(object):
             at_dict = pn.getAtomDict()
             pn.atomicData.setDataFileDict(current)
         else: 
-            pn.log_.error('The argument predef must be the label of a predefined dictionary', calling=self.calling)
+            pn.log_.error('The argument predef must be the label of a predefined dictionary', 
+                          calling=self.calling)
         
         for item in sorted(at_dict):                                                              
             at_dict[item].printSources()
     
+    def _initChianti(self):
+        self.ChiantiIONS = {'atom':[], 'coll':[]}
+        self.Chianti_path = None
+        
+        if pn.config.INSTALLED['Chianti']:
     
+            self.Chianti_path = os.environ['XUVTOP']
+            masterlist = '{0}/masterlist/masterlist.ions'.format(self.Chianti_path)
+            try:
+                with open(masterlist) as master:
+                    for line in master.readlines():
+                        atom = line.split()[0]
+                        elem = atom.split('_')[0]
+                        coll_file = '{0}/{1}/{2}/{2}.splups'.format(self.Chianti_path, elem, atom)
+                        atom_file = '{0}/{1}/{2}/{2}.wgfa'.format(self.Chianti_path, elem, atom)
+                        if os.path.exists(coll_file): 
+                            self.ChiantiIONS['coll'].append(atom)
+                        if os.path.exists(atom_file):
+                            self.ChiantiIONS['atom'].append(atom)
+            except:
+                pn.log_.warn('File not found {}, no Chianti data vailable'.format(masterlist), 
+                             calling='_initChianti')
+        
     def printPoem(self, yr=0):
         """
         Print one of Wiese et al. spectroscopic poems
@@ -450,4 +519,186 @@ class _ManageAtomicData(object):
                 self.printPoem(yr=66)
             else:
                 self.printPoem(yr=96)
+
+def extract_flt(str_):
+    """
+    Return the first float in str_, removing the no digit (and no dot) leading part of it.
+    Ex:
+    extract_flt('123.00?') -> 123.00
+    """
+    res = ''
+    for l in str_:
+        if l.isdigit() or l == '.':
+            res += l
+        else:
+            break
+    if res == '':
+        return np.nan
+    else:
+        return float(res)
+
+
+def readNIST(NISTfile):
+    """
+    The NIST levels file must be obtained from this page:
+        http://physics.nist.gov/PhysRefData/ASD/levels_form.html
+    with the following options:
+        Level Units: cm-1
+        Format output: ASCII
+        Display output: in its entirely
+        Energy ordered
+        Level Information: Principal configuration, Principal term, Level, J
+        Bibliographic references
+    """
+    data = np.genfromtxt(NISTfile, comments = '-', 
+                    delimiter = '|', names = 'conf, term, J, energy, ref', 
+                    dtype=('a23', 'a9', 'a4', 'float', 'a10'), autostrip=True,
+                    converters = {'energy':extract_flt})
+    data = data[data['J'] != '']
+    previous_ref = ''
+    previous_conf = ''
+    previous_term = ''
+    for d in data:
+        if d['conf'] == '':
+            d['conf'] = previous_conf
+        else:
+            previous_conf = d['conf']
+        if d['term'] == '':
+            d['term'] = previous_term
+        else:
+            previous_term = d['term']
+        if d['ref'] == '':
+            d['ref'] = previous_ref
+        else:
+            previous_ref = d['ref']
+        if '?' in d['J']:
+            d['J'] = d['J'].split('?')[0]
+        if d['J'] == '':
+            d['J'] = 0.
+        elif '/' in d['J']:
+            d['J'] = '{0:.1f}'.format(float(d['J'].split('/')[0]) / float(d['J'].split('/')[1]))
+        else:
+            d['J'] = '{0:.1f}'.format(float(d['J']))
+           
+    data = data[data['energy'].argsort()]
+    data = data.astype([('conf', 'a23'), ('term', 'a9'), ('J', 'float'), ('energy', 'float'), ('ref', 'a10')])
+    return data
+
+def getLevelsNIST(atom, Nmax = None):
+    """
+    return a numpy.array containing the NIST data related to the levels for the given atom
+    The keys of the recarry are: conf, term, J, energy, ref
+    Example:
+        data = getLevelsNIST('O3')
+        energies = data['energy']
+    """
+    
+    elem, spec = parseAtom(atom)
+    elem = elem.lower()
+    spec = int_to_roman(int(spec)).lower()
+    atom_str = '{0}_{1}'.format(elem, spec)
+    level_file = '{0}_levels.dat'.format(atom_str)
+    file_ = execution_path('../atomic_data/levels/{0}'.format(level_file))
+    if os.path.isfile(file_):
+        data = readNIST(file_)
+        pn.log_.message('Reading energies and stat weights from {0}'.format(level_file), calling='getLevelsNIST')
+        if Nmax is not None:
+            if Nmax < len(data):
+                data = data[0:Nmax]
+        return data
+    else:
+        return None
+    
+def _atom_fits2ascii(filename):
+    """
+    Transform a *atom*.fits file into an *atom*.dat file.
+    """
+    strs = filename.split('/')[-1].split('_')
+    elem = strs[0].capitalize()
+    spec = roman_to_int(strs[1])
+#    type = strs[2]
+    pn.atomicData.setDataFile(filename.split('/')[-1])
+    atom = pn.Atom(elem, spec)
+    atom.printSources()
+    print('')
+    fileout = raw_input('Enter the name of the output file (between {0[0]}_{0[1]}_{0[2]}_ and .dat:'.format(strs))
+    
+    fout = open('{0[0]}_{0[1]}_{0[2]}_{1}.dat'.format(strs,fileout), 'w')
+    fout.write('Aij\n')
+#    str_ = ''
+#    for i in np.arange(atom.NLevels):
+#        str_ += '1/s '
+#    str_ += '\n'
+    str_ = '1/s ' * atom.NLevels + '\n'
+    fout.write(str_)
+    for a1 in atom.getA():
+        str_ = ''
+        for a2 in a1:
+            str_ += '{0:10.7e}'.format(a2)
+            str_ += ' '
+        str_ += '\n'
+        fout.write(str_)
+    for item in atom.AtomData.AtomHeader.iteritems():
+        if 'SPECTRUM' in item[0] or 'ATOM' in item[0] or 'GSCONFIG' in item[0]:
+            fout.write('*** ' + item[0] + ' ' + str(item[1]) + '\n')
+        if 'NOTE' in item[0]:
+            if 'Energy' not in item[1]:
+                N_Note = item[0].split('NOTE')[1]
+                str_N_Note = str(N_Note.split('_')[0])
+                fout.write('*** SOURCE' + str_N_Note + ' ' + atom.AtomData.AtomHeader.get('SOURCE'+str_N_Note)  + '\n')
+                fout.write('*** ' + item[0] + ' ' + str(item[1]) + '\n')
+    
+    fout.close()
+    
+def _coll_fits2ascii(filename, overwrite=None):
+    """
+    Transform a *coll*.fits file into an *coll*.dat file.
+    """
+    strs = filename.split('/')[-1].split('_')
+    elem = strs[0].capitalize()
+    spec = roman_to_int(strs[1])
+    pn.atomicData.setDataFile(filename.split('/')[-1])
+    atom = pn.Atom(elem, spec)
+    #atom.printSources()
+    fileout = '{}.dat'.format(filename.split('.')[0])
+    
+    if overwrite is not True:
+        if os.path.exists(fileout):
+            erase = raw_input('{} exists, overwrite?'.format(fileout))
+            if erase != 'y':
+                return
+    fout = open(fileout, 'w')
+    fout.write('*** {0}{1} collision strengths data\n'.format(elem, strs[1].upper()))
+    str_ = '0 0'
+    for t in atom.getTemArray():
+        str_ += ' {0:9.3e}'.format(t)
+    str_ += '\n'
+    fout.write(str_)
+    for omega in atom.getOmegaArray():
+        j = strExtract(omega, 'Omega(', '->')
+        i = strExtract(omega, '->', ')')
+        omegs = strExtract(omega, '[', ']')
+        str_ = '{0} {1}'.format(i,j)
+        for omeg in omegs.split():
+            str_ += ' {0:9.3e}'.format(float(omeg))
+        str_ += '\n'
+        fout.write(str_)
+        
+    for item in atom.CollData.CollHeader.iteritems():
+        if 'SPECTRUM' in item[0] or 'ATOM' in item[0] or 'GSCONFIG' in item[0]:
+            fout.write('*** ' + item[0] + ' ' + str(item[1]) + '\n')
+        if 'TUNIT1' == item[0]:
+            fout.write('*** T_UNIT ' + str(item[1]) + '\n') 
+        if 'SOURCE' in item[0]:
+            N_Source = item[0].split('SOURCE')[1]
+            str_N_Source = str(N_Source.split('_')[0])
+            fout.write('*** ' + item[0] + ' ' + str(item[1]) + '\n')
+            try:
+                fout.write('*** NOTE' + str_N_Source + ' ' + atom.CollData.CollHeader.get('NOTE'+str_N_Source)  + '\n')
+            except:
+                fout.write('*** NOTE' + str_N_Source + ' collision strengths \n')
+    print('{} done'.format(fileout))
+    fout.close()
+    
+    
     
